==> pycfd-1.1.6-py3-none-any.whl: pycfd/__init__.py <==
# pyfoam\pyfoam\core\__init__.py

from .meshing.mesh import StructuredMesh, UnstructuredMesh
from .conditions.condition import BoundaryCondition, DirichletCondition, NeumannCondition, InitialCondition, ScalarInitialCondition
from .solvers.fem_solver import FEMSolver
from .solvers.fem_poisson_solver import PoissonFEMSolver
from .solvers.fem_heat_solver import HeatFEMSolver
from .solvers.fem_helmholtz_solver import HelmholtzFEMSolver
from .solvers.fvm_solver import FVMSolver
from .solvers.fvm_poisson_solver import PoissonFVMSolver
from .solvers.fvm_heat_solver import HeatFVMSolver
from .solvers.fvm_helmholtz_solver import HelmholtzFVMSolver
from .solvers.cfds.navier_stocks_solver import NavierStokesFEM
from .solvers.cfds.navier_stocks_solver import NavierStokesFVM
from .solvers.cfds.navier_stocks_solver import NavierStokesFDM
from .solvers.cfds.cfd_solver import CFDSolver
from symbolicly.symbolic_regression import generate_multi_indices, build_design_matrix, symbolic_regression_solution, approximate_poisson_solution, approximate_heat_solution, approximate_helmholtz_solution, approximate_general_pde_solution

__all__ = [
    "StructuredMesh",
    "UnstructuredMesh",
    "BoundaryCondition",
    "DirichletCondition",
    "NeumannCondition",
    "InitialCondition",
    "ScalarInitialCondition",
    "FEMSolver",
    "PoissonFEMSolver",
    "HeatFEMSolver",
    "HelmholtzFEMSolver",
    "FVMSolver",
    "PoissonFVMSolver",
    "HeatFVMSolver",
    "HelmholtzFVMSolver",
    "NavierStokesFEM",
    "NavierStokesFVM",
    "NavierStokesFDM",
    "CFDSolver",
    "generate_multi_indices",
    "build_design_matrix",
    "symbolic_regression_solution",
    "approximate_poisson_solution",
    "approximate_heat_solution",
    "approximate_helmholtz_solution",
    "approximate_general_pde_solution"]

==> pycfd-1.1.7-py3-none-any.whl: pycfd/__init__.py <==
# pyfoam\pyfoam\core\__init__.py

from .meshing.mesh import StructuredMesh, UnstructuredMesh
from .conditions.condition import BoundaryCondition, DirichletCondition, NeumannCondition, InitialCondition, ScalarInitialCondition
from .solvers.fem_solver import FEMSolver
from .solvers.fem_poisson_solver import PoissonFEMSolver
from .solvers.fem_heat_solver import HeatFEMSolver
from .solvers.fem_helmholtz_solver import HelmholtzFEMSolver
from .solvers.fvm_solver import FVMSolver
from .solvers.fvm_poisson_solver import PoissonFVMSolver
from .solvers.fvm_heat_solver import HeatFVMSolver
from .solvers.fvm_helmholtz_solver import HelmholtzFVMSolver
from .solvers.cfds.navier_stocks_solver import NavierStokesFEM
from .solvers.cfds.navier_stocks_solver import NavierStokesFVM
from .solvers.cfds.navier_stocks_solver import NavierStokesFDM
from .solvers.cfds.cfd_solver import CFDSolver
from .symbolicly.symbolic_regression import generate_multi_indices, build_design_matrix, symbolic_regression_solution, approximate_poisson_solution, approximate_heat_solution, approximate_helmholtz_solution, approximate_general_pde_solution

__all__ = [
    "StructuredMesh",
    "UnstructuredMesh",
    "BoundaryCondition",
    "DirichletCondition",
    "NeumannCondition",
    "InitialCondition",
    "ScalarInitialCondition",
    "FEMSolver",
    "PoissonFEMSolver",
    "HeatFEMSolver",
    "HelmholtzFEMSolver",
    "FVMSolver",
    "PoissonFVMSolver",
    "HeatFVMSolver",
    "HelmholtzFVMSolver",
    "NavierStokesFEM",
    "NavierStokesFVM",
    "NavierStokesFDM",
    "CFDSolver",
    "generate_multi_indices",
    "build_design_matrix",
    "symbolic_regression_solution",
    "approximate_poisson_solution",
    "approximate_heat_solution",
    "approximate_helmholtz_solution",
    "approximate_general_pde_solution"]
